"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCapabilities = getCapabilities;
exports.isBatchingSupported = isBatchingSupported;
const types_1 = require("@lifi/types");
const accounts_1 = require("viem/accounts");
const utils_1 = require("viem/utils");
const config_js_1 = require("../../config.js");
async function getCapabilities(client, parameters = {}) {
    const account_raw = parameters?.account ?? client.account;
    if (!account_raw) {
        throw new Error('Account not found');
    }
    const account = (0, accounts_1.parseAccount)(account_raw);
    const capabilities_raw = await client.request({
        method: 'wallet_getCapabilities',
        params: [account.address],
    }, {
        dedupe: true,
        retryCount: 0,
    });
    const capabilities = {};
    for (const [key, value] of Object.entries(capabilities_raw)) {
        capabilities[Number(key)] = value;
    }
    return capabilities;
}
async function isBatchingSupported({ client, chainId, }) {
    const _client = client ??
        (await config_js_1.config.getProvider(types_1.ChainType.EVM)?.getWalletClient?.());
    if (!_client) {
        throw new Error('WalletClient is not provided.');
    }
    try {
        const capabilities = (await (0, utils_1.getAction)(_client, getCapabilities, 'getCapabilities')(undefined));
        return capabilities[chainId]?.atomicBatch?.supported ?? false;
    }
    catch {
        return false;
    }
}
//# sourceMappingURL=isBatchingSupported.js.map